@@ -19,6 +19,9 @@ extern crate dmntk_feel_grammar;
 use dmntk_feel_grammar::lalr_rust_tables;
 
 fn main() {
-  // generate LALR parsing tables for FEEL grammar
-  lalr_rust_tables();
+  if std::env::var("CARGO_FEATURE_PARSING_TABLES").is_ok() {
+    // generate new LALR parsing tables for FEEL grammar
+    // when executed with --features=parsing-tables
+    lalr_rust_tables();
+  }
 }
