@@ -16,14 +16,12 @@
 
 //! Implementation of the lexer for `FEEL` grammar.
 
+use self::errors::*;
+use crate::lalr::TokenType;
+use dmntk_common::Result;
 use dmntk_feel::context::FeelContext;
 use dmntk_feel::values::VALUE_NULL;
-use {
-  self::errors::*,
-  crate::lalr::TokenType,
-  dmntk_common::Result,
-  dmntk_feel::{Name, Scope},
-};
+use dmntk_feel::{Name, Scope};
 
 /// Definition of a single space character.
 const WS: char = ' ';
@@ -1149,44 +1147,44 @@ mod tests {
     assert!(is_separator('['));
     assert!(is_separator(']'));
     assert!(is_separator('}'));
-    assert_eq!(false, is_separator('('));
-    assert_eq!(false, is_separator('{'));
-    assert_eq!(false, is_separator('?'));
+    assert!(!is_separator('('));
+    assert!(!is_separator('{'));
+    assert!(!is_separator('?'));
   }
 
   #[test]
   fn test_is_additional_name_symbol() {
-    assert_eq!(true, is_additional_name_symbol('.'));
-    assert_eq!(true, is_additional_name_symbol('/'));
-    assert_eq!(true, is_additional_name_symbol('-'));
-    assert_eq!(true, is_additional_name_symbol('\''));
-    assert_eq!(true, is_additional_name_symbol('+'));
-    assert_eq!(true, is_additional_name_symbol('*'));
-    assert_eq!(false, is_additional_name_symbol(' '));
-    assert_eq!(false, is_additional_name_symbol('$'));
-    assert_eq!(false, is_additional_name_symbol(':'));
-    assert_eq!(false, is_additional_name_symbol('('));
-    assert_eq!(false, is_additional_name_symbol(')'));
-    assert_eq!(false, is_additional_name_symbol('['));
-    assert_eq!(false, is_additional_name_symbol(']'));
-    assert_eq!(false, is_additional_name_symbol('{'));
-    assert_eq!(false, is_additional_name_symbol('}'));
-    assert_eq!(false, is_additional_name_symbol('?'));
+    assert!(is_additional_name_symbol('.'));
+    assert!(is_additional_name_symbol('/'));
+    assert!(is_additional_name_symbol('-'));
+    assert!(is_additional_name_symbol('\''));
+    assert!(is_additional_name_symbol('+'));
+    assert!(is_additional_name_symbol('*'));
+    assert!(!is_additional_name_symbol(' '));
+    assert!(!is_additional_name_symbol('$'));
+    assert!(!is_additional_name_symbol(':'));
+    assert!(!is_additional_name_symbol('('));
+    assert!(!is_additional_name_symbol(')'));
+    assert!(!is_additional_name_symbol('['));
+    assert!(!is_additional_name_symbol(']'));
+    assert!(!is_additional_name_symbol('{'));
+    assert!(!is_additional_name_symbol('}'));
+    assert!(!is_additional_name_symbol('?'));
   }
 
   #[test]
   fn test_flatten_name_parts() {
     assert_eq!(
       "left middle right",
-      flatten_name_parts(&vec!["left".to_string(), "middle".to_string(), "right".to_string()])
+      flatten_name_parts(&["left".to_string(), "middle".to_string(), "right".to_string()])
     );
-    assert_eq!("a.b", flatten_name_parts(&vec!["   a  ".to_string(), " . ".to_string(), "  b ".to_string()]));
-    assert_eq!("a/b", flatten_name_parts(&vec!["   a  ".to_string(), " / ".to_string(), "  b ".to_string()]));
-    assert_eq!("a-b", flatten_name_parts(&vec!["   a  ".to_string(), " - ".to_string(), "  b ".to_string()]));
-    assert_eq!("a'b", flatten_name_parts(&vec!["   a  ".to_string(), " ' ".to_string(), "  b ".to_string()]));
-    assert_eq!("a+b", flatten_name_parts(&vec!["   a  ".to_string(), " + ".to_string(), "  b ".to_string()]));
-    assert_eq!("a*b", flatten_name_parts(&vec!["   a  ".to_string(), " * ".to_string(), "  b ".to_string()]));
-    assert_eq!("", flatten_name_parts(&vec!["".to_string(), "".to_string(), "".to_string()]));
-    assert_eq!("", flatten_name_parts(&vec![]));
+    assert_eq!("a.b", flatten_name_parts(&["   a  ".to_string(), " . ".to_string(), "  b ".to_string()]));
+    assert_eq!("a/b", flatten_name_parts(&["   a  ".to_string(), " / ".to_string(), "  b ".to_string()]));
+    assert_eq!("a-b", flatten_name_parts(&["   a  ".to_string(), " - ".to_string(), "  b ".to_string()]));
+    assert_eq!("a'b", flatten_name_parts(&["   a  ".to_string(), " ' ".to_string(), "  b ".to_string()]));
+    assert_eq!("a+b", flatten_name_parts(&["   a  ".to_string(), " + ".to_string(), "  b ".to_string()]));
+    assert_eq!("a*b", flatten_name_parts(&["   a  ".to_string(), " * ".to_string(), "  b ".to_string()]));
+    assert_eq!("", flatten_name_parts(&["".to_string(), "".to_string(), "".to_string()]));
+    assert_eq!("", flatten_name_parts(&[]));
   }
 }
