@@ -16,18 +16,52 @@
 
 //! Implementation of the `LALR` parser for `FEEL` grammar.
 
+use self::errors::*;
+use crate::lalr::{TokenType, *};
+use crate::lexer::{Lexer, TokenValue};
+use dmntk_common::Result;
 use dmntk_feel::context::FeelContext;
 use dmntk_feel::values::VALUE_NULL;
-use dmntk_feel::FeelType;
-use {
-  self::errors::*,
-  crate::{
-    lalr::{TokenType, *},
-    lexer::{Lexer, TokenValue},
-  },
-  dmntk_common::Result,
-  dmntk_feel::{AstNode, Name, Scope},
-};
+use dmntk_feel::{AstNode, FeelType, Name, Scope};
+
+/// Parses textual expression using `grammar rule 2`.
+pub fn parse_textual_expression(scope: &Scope, input: &str, trace: bool) -> Result<AstNode> {
+  Parser::new(scope, TokenType::StartTextualExpression, input, trace).parse()
+}
+
+/// Parses textual expressions using `grammar rule 3`.
+pub fn parse_textual_expressions(scope: &Scope, input: &str, trace: bool) -> Result<AstNode> {
+  Parser::new(scope, TokenType::StartTextualExpressions, input, trace).parse()
+}
+
+/// Parses the unary tests using `grammar rule 17`.
+pub fn parse_unary_tests(scope: &Scope, input: &str, trace: bool) -> Result<AstNode> {
+  Parser::new(scope, TokenType::StartUnaryTests, input, trace).parse()
+}
+
+/// Parses a `FEEL` name using `grammar rule 25`.
+pub fn parse_name(scope: &Scope, input: &str, trace: bool) -> Result<Name> {
+  if let AstNode::Name(name) = Parser::new(scope, TokenType::StartTextualExpressions, input, trace).parse()? {
+    Ok(name)
+  } else {
+    Err(not_a_name(input))
+  }
+}
+
+/// Parses the longest `FEEL` name using `grammar rule 25`.
+pub fn parse_longest_name(input: &str) -> Result<Name> {
+  parse_name(&Default::default(), input, false)
+}
+
+/// Parses a boxed expression using `grammar rule 53`.
+pub fn parse_boxed_expression(scope: &Scope, input: &str, trace: bool) -> Result<AstNode> {
+  Parser::new(scope, TokenType::StartBoxedExpression, input, trace).parse()
+}
+
+/// Parses a context using `grammar rule 59`.
+pub fn parse_context(scope: &Scope, input: &str, trace: bool) -> Result<AstNode> {
+  Parser::new(scope, TokenType::StartContext, input, trace).parse()
+}
 
 #[derive(Debug, Clone)]
 enum Action {
@@ -1087,13 +1121,13 @@ impl<'parser> Parser<'parser> {
   }
 }
 
-/// Definitions of errors raised by the parser.
-pub mod errors {
+/// Definitions of errors raised by [parser](crate::parser) module.
+mod errors {
   use dmntk_common::DmntkError;
 
-  /// Parser errors.
-  #[derive(Debug, PartialEq)]
+  /// Definition of errors raised by [Parser](super::Parser).
   enum ParserError {
+    NotAName(String),
     InvalidParseResult,
     SyntaxError,
     NegatedUnaryTestsRequireNotKeyword(String),
@@ -1106,8 +1140,12 @@ pub mod errors {
   }
 
   impl std::fmt::Display for ParserError {
+    ///
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
       match self {
+        ParserError::NotAName(s) => {
+          write!(f, "expected `FEEL` name on input but found `{}`", s)
+        }
         ParserError::InvalidParseResult => {
           write!(f, "invalid parse result, expected non empty AST node as a result when parser accepts input")
         }
@@ -1120,15 +1158,19 @@ pub mod errors {
       }
     }
   }
-
+  ///
+  pub fn not_a_name(s: &str) -> DmntkError {
+    ParserError::NotAName(s.to_owned()).into()
+  }
+  ///
   pub fn invalid_parse_result() -> DmntkError {
     ParserError::InvalidParseResult.into()
   }
-
+  ///
   pub fn syntax_error() -> DmntkError {
     ParserError::SyntaxError.into()
   }
-
+  ///
   pub fn negated_unary_tests_require_not_keyword(s: String) -> DmntkError {
     ParserError::NegatedUnaryTestsRequireNotKeyword(s).into()
   }
