@@ -14,12 +14,10 @@
  * SOFTWARE.
  */
 
+use super::{accept, empty_scope};
+use crate::lalr::TokenType::StartTextualExpression;
 use dmntk_feel::values::VALUE_NULL;
-use {
-  super::{accept, empty_scope},
-  crate::lalr::TokenType::StartTextualExpression,
-  dmntk_feel::Scope,
-};
+use dmntk_feel::Scope;
 
 /// Utility function that compares the given name with expected name after parsing.
 fn accept_name(scope: &Scope, name: &str, expected: &str) {
