@@ -14,8 +14,10 @@
  * SOFTWARE.
  */
 
+use super::accept;
+use crate::lalr::TokenType::*;
 use dmntk_feel::values::VALUE_NULL;
-use {super::accept, crate::lalr::TokenType::*, dmntk_feel::Scope};
+use dmntk_feel::Scope;
 
 #[test]
 fn test_numeric() {
